# My first project
## Sekcja 1
This project can subtract any number you give it example
```python
print(mep(1, 7))
```
``
Output would be -6
``
<span style="font-size: 30px;">To jest</span> tekst **pogrubiony**